@@ -22,23 +22,25 @@
 #'
 #' @inheritParams stats::glm.control
 #' @aliases brglm_control
-#' @param epsilon positive convergence tolerance epsilon.
+#' @param epsilon positive convergence tolerance epsilon. Default is \code{1e-06}.
 #' @param maxit integer giving the maximal number of iterations
-#'     allowed.
+#'     allowed. Default is \code{100}.
 #' @param trace logical indicating if output should be produced for
-#'     each iteration.
+#'     each iteration. Default is \code{FALSE}.
 #' @param type the type of fitting method to be used. The options are
 #'     \code{AS_mean} (mean-bias reducing adjusted scores),
 #'     \code{AS_median} (median-bias reducting adjusted scores),
-#'     \code{AS_mixed} (bias reduction using mixed score adjustents; default),
-#'     \code{correction} (asymptotic bias correction) and \code{ML}
-#'     (maximum likelihood).
+#'     \code{AS_mixed} (bias reduction using mixed score adjustents;
+#'     default), \code{correction} (asymptotic bias correction) and
+#'     \code{ML} (maximum likelihood).
 #' @param transformation the transformation of the dispersion to be
 #'     estimated. Default is \code{identity}. See Details.
 #' @param slowit a positive real used as a multiplier for the
-#'     stepsize. The smaller it is the smaller the steps are.
+#'     stepsize. The smaller it is the smaller the steps are. Default is \code{1}.
 #' @param max_step_factor the maximum number of step halving steps to
-#'     consider.
+#'     consider. Default is \code{12}.
+#' @param response_adjustment a (small) positive constant or a vector
+#'     of such. Default is \code{NULL}. See Details.
 #'
 #' @details \code{\link{brglmControl}} provides default values and
 #'     sanity checking for the various constants that control the
@@ -56,6 +58,22 @@
 #'      supplying a list of two expressions (transformation and
 #'      inverse transformation). See the examples for more details.
 #'
+#'      The value of \code{response_adjustment} is only relevant if
+#'      \code{\link{brglmFit}} is called with \code{start = NULL}, and
+#'      \code{family} is \code{\link{binomial}} or
+#'      \code{\link{poisson}}. For those models, an initial maximum
+#'      likelihood fit is obtained on adjusted data to provide
+#'      starting values for the iteration in \code{brglmFit}. The
+#'      value of \code{response_adjustment} governs how the data is
+#'      adjusted. Specifically, if \code{family} is \code{binomial},
+#'      then the responses and totals are adjusted by and \code{2 *
+#'      response_adjustment}, respectively; if \code{family} is
+#'      \code{poisson}, then the responses are adjusted by and
+#'      \code{response_adjustment}. \code{response_adjustment = NULL}
+#'      (default) is equivalent to setting it to
+#'      "number of parameters"/"number of observations". 
+#'      
+#'
 #' \code{brglm_control} is an alias to \code{brglmControl}.
 #'
 #' @return a list with components named as the arguments, including
@@ -64,7 +82,7 @@
 #'
 #' @author Ioannis Kosmidis \email{ioannis.kosmidis@warwick.ac.uk}
 #'
-#' @seealso \code{\link{brglmFit}} and \code{\link{glm.fit}}
+#' @seealso \code{\link{brglm_fit}} and \code{\link{glm.fit}}
 #'
 #' @examples
 #'
@@ -88,11 +106,12 @@
 #' coef(coalitionBRc, model = "dispersion")
 #'
 #' @export
-brglmControl <- function(epsilon = 1e-08, maxit = 100,
+brglmControl <- function(epsilon = 1e-06, maxit = 100,
                          trace = FALSE,
                          type = c("AS_mixed", "AS_mean", "AS_median", "correction", "ML"),
                          transformation = "identity",
                          slowit = 1,
+                         response_adjustment = NULL,
                          max_step_factor = 12) {
     type <- match.arg(type)
 
@@ -124,6 +143,7 @@ brglmControl <- function(epsilon = 1e-08, maxit = 100,
     if (!is.numeric(epsilon) || epsilon <= 0)
         stop("value of 'epsilon' must be > 0")
     list(epsilon = epsilon, maxit = maxit, trace = trace,
+         response_adjustment = response_adjustment,
          type = type,
          Trans = Trans,
          inverseTrans = inverseTrans,
